@@ -64,7 +64,10 @@ class DatasetOut:
 
         started: Union[Unset, str] = UNSET
         if not isinstance(self.started, Unset):
-            started = self.started.isoformat()
+            if self.started:
+                started = self.started.isoformat()
+            else:
+                started = None
 
         duration = self.duration
         ranking = self.ranking
